deeplake.auto.unstructured
==========================
.. toctree::
    :maxdepth: 2

    deeplake.auto.unstructured.base
    deeplake.auto.unstructured.image_classification <deeplake.auto.unstructured.image-classification>
    deeplake.auto.unstructured.kaggle